@@ -1,9 +1,9 @@
 import json
 import logging
+import time
 from collections import OrderedDict
 from copy import copy
 from pprint import pformat
-from time import sleep
 
 import requests
 from six import wraps
@@ -134,6 +134,15 @@ class ProviderRequestProxy(object):
         else:
             return response.content
 
+    def set_file_caret_to_start(self, **request_arguments):
+        files_in_request = request_arguments.get('files')
+        if files_in_request:
+            try:
+                for key in files_in_request.keys():
+                    files_in_request[key].seek(0)
+            except Exception as exc:
+                logger.debug('Failed to put file pointer to the start of the file with exc: %s', exc, exc_info=exc)
+
     def request_with_retry(self, method, **request_arguments):
         request_arguments = self.augment_request_arguments(**request_arguments)
         retries = 0
@@ -141,6 +150,7 @@ class ProviderRequestProxy(object):
 
         while retries < self.retries:
             try:
+                self.set_file_caret_to_start(**request_arguments)
                 response = getattr(requests, method)(**request_arguments)
                 if 400 <= response.status_code < 500:
                     http_error_msg = '%s Client Error: %s for url: %s %s' % \
@@ -161,7 +171,7 @@ class ProviderRequestProxy(object):
                 logger.debug('Retry request %s %s', method, request_arguments['url'])
                 retries += 1
                 retry_errors.append(exc)
-                sleep(self.retry_delay)
+                time.sleep(self.retry_delay)
             except requests.ConnectionError as exc:
                 retry_errors.append(exc)
                 raise ProviderHTTPServiceException('Service is not working with error: %s' % exc)
@@ -285,7 +295,7 @@ class ReboticsBaseProvider(object):
     def is_retailer_identifier_used(self):
         header_keys = self.headers.keys()
         return ('x-retailer-codename' in header_keys or 'x-retailer-id' in header_keys) \
-            and \
+               and \
                ('x-retailer-secret-key' in header_keys)
 
 
