@@ -98,3 +98,22 @@ class FVMProvider(ReboticsBaseProvider):
                 'title': title,
             }
         )
+
+    @remote_service('/api/rcdb/latest/')
+    def get_latest_rcdb(self, model_codename, retailer_codename=None, with_images=False):
+        payload = {
+            'model_codename': model_codename,
+            'with_images': with_images,
+        }
+        if retailer_codename is not None and self.codename is None:
+            payload['retailer_codename'] = retailer_codename
+        return self.session.post(json=payload)
+
+    @remote_service('/api/rcdb/refresh/')
+    def rcdb_refresh(self, model_codename, retailer_codename, with_images=False):
+        # only admin can do that
+        return self.session.post(json={
+            'model_codename': model_codename,
+            'retailer_codename': retailer_codename,
+            'with_images': with_images,
+        })
